==> jc-1.4.0.tar.gz: gnu/regexp/REFilterInputStream.h <==
// public class gnu.regexp.REFilterInputStream

// class file dependencies
// @dep_class bdc13d1b59cd8d32 gnu_regexp_REFilterInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_regexp_REFilterInputStream_H_
#define _JC_gnu_regexp_REFilterInputStream_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexedInputStream$object;
struct _jc_gnu_regexp_RE$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_regexp_REFilterInputStream$sub_refs	_jc_gnu_regexp_REFilterInputStream$sub_refs;
typedef struct _jc_gnu_regexp_REFilterInputStream$sub_nonrefs	_jc_gnu_regexp_REFilterInputStream$sub_nonrefs;
typedef struct _jc_gnu_regexp_REFilterInputStream$refs	_jc_gnu_regexp_REFilterInputStream$refs;
typedef struct _jc_gnu_regexp_REFilterInputStream$nonrefs	_jc_gnu_regexp_REFilterInputStream$nonrefs;
typedef struct _jc_gnu_regexp_REFilterInputStream$object	_jc_gnu_regexp_REFilterInputStream$object;

typedef const struct _jc_gnu_regexp_REFilterInputStream$vmethods	_jc_gnu_regexp_REFilterInputStream$vmethods;
typedef const struct _jc_gnu_regexp_REFilterInputStream$vtable	_jc_gnu_regexp_REFilterInputStream$vtable;
typedef const struct _jc_gnu_regexp_REFilterInputStream$vtype	_jc_gnu_regexp_REFilterInputStream$vtype;

// Constructors
extern void _jc_gnu_regexp_REFilterInputStream$method$_init$3fa7148687939fa5(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_gnu_regexp_RE$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_gnu_regexp_REFilterInputStream$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *);
extern jint _jc_gnu_regexp_REFilterInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *);
extern jint _jc_gnu_regexp_REFilterInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *, struct _jc_byte_array *);
extern jint _jc_gnu_regexp_REFilterInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_REFilterInputStream$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_gnu_regexp_REFilterInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_regexp_REFilterInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_regexp_REFilterInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_gnu_regexp_REFilterInputStream$vmethods {
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *);
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *, struct _jc_byte_array *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_gnu_regexp_REFilterInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_regexp_REFilterInputStream$vmethods	gnu_regexp_REFilterInputStream;
};

// Vtype
struct _jc_gnu_regexp_REFilterInputStream$vtype {
	_jc_type			type;
	_jc_gnu_regexp_REFilterInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_REFilterInputStream$sub_refs {
	struct _jc_gnu_regexp_RE$object	*expr;
	struct _jc_java_lang_String$object	*replace;
	struct _jc_java_lang_String$object	*buffer;
	struct _jc_gnu_regexp_CharIndexedInputStream$object	*stream;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_REFilterInputStream$refs {
    _jc_gnu_regexp_REFilterInputStream$sub_refs	gnu_regexp_REFilterInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_REFilterInputStream$sub_nonrefs {
	jint	bufpos;
	jint	offset;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_REFilterInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_regexp_REFilterInputStream$sub_nonrefs	gnu_regexp_REFilterInputStream;
};

// Object instance structure
struct _jc_gnu_regexp_REFilterInputStream$object {
	_jc_gnu_regexp_REFilterInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_REFilterInputStream$vtype	*vtype;
	_jc_gnu_regexp_REFilterInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_REFilterInputStream$vtype _jc_gnu_regexp_REFilterInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_REFilterInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_REFilterInputStream$class_object;

#endif	/* _JC_gnu_regexp_REFilterInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/REFilterInputStream.h <==
// public class gnu.regexp.REFilterInputStream

// class file dependencies
// @dep_class bdc13d1b59cd8d32 gnu_regexp_REFilterInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_regexp_REFilterInputStream_H_
#define _JC_gnu_regexp_REFilterInputStream_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexedInputStream$object;
struct _jc_gnu_regexp_RE$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_regexp_REFilterInputStream$sub_refs	_jc_gnu_regexp_REFilterInputStream$sub_refs;
typedef struct _jc_gnu_regexp_REFilterInputStream$sub_nonrefs	_jc_gnu_regexp_REFilterInputStream$sub_nonrefs;
typedef struct _jc_gnu_regexp_REFilterInputStream$refs	_jc_gnu_regexp_REFilterInputStream$refs;
typedef struct _jc_gnu_regexp_REFilterInputStream$nonrefs	_jc_gnu_regexp_REFilterInputStream$nonrefs;
typedef struct _jc_gnu_regexp_REFilterInputStream$object	_jc_gnu_regexp_REFilterInputStream$object;

typedef const struct _jc_gnu_regexp_REFilterInputStream$vmethods	_jc_gnu_regexp_REFilterInputStream$vmethods;
typedef const struct _jc_gnu_regexp_REFilterInputStream$vtable	_jc_gnu_regexp_REFilterInputStream$vtable;
typedef const struct _jc_gnu_regexp_REFilterInputStream$vtype	_jc_gnu_regexp_REFilterInputStream$vtype;

// Constructors
extern void _jc_gnu_regexp_REFilterInputStream$method$_init$3fa7148687939fa5(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_gnu_regexp_RE$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_regexp_REFilterInputStream$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_regexp_REFilterInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_regexp_REFilterInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern jint _jc_gnu_regexp_REFilterInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_REFilterInputStream$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_gnu_regexp_REFilterInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_regexp_REFilterInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_regexp_REFilterInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_gnu_regexp_REFilterInputStream$vmethods {
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_regexp_REFilterInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_REFilterInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_regexp_REFilterInputStream$vmethods	gnu_regexp_REFilterInputStream;
};

// Vtype
struct _jc_gnu_regexp_REFilterInputStream$vtype {
	_jc_type			type;
	_jc_gnu_regexp_REFilterInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_REFilterInputStream$sub_refs {
	struct _jc_gnu_regexp_RE$object	*expr;
	struct _jc_java_lang_String$object	*replace;
	struct _jc_java_lang_String$object	*buffer;
	struct _jc_gnu_regexp_CharIndexedInputStream$object	*stream;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_REFilterInputStream$refs {
    _jc_gnu_regexp_REFilterInputStream$sub_refs	gnu_regexp_REFilterInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_REFilterInputStream$sub_nonrefs {
	jint	bufpos;
	jint	offset;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_REFilterInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_regexp_REFilterInputStream$sub_nonrefs	gnu_regexp_REFilterInputStream;
};

// Object instance structure
struct _jc_gnu_regexp_REFilterInputStream$object {
	_jc_gnu_regexp_REFilterInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_REFilterInputStream$vtype	*vtype;
	_jc_gnu_regexp_REFilterInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_REFilterInputStream$vtype _jc_gnu_regexp_REFilterInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_REFilterInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_REFilterInputStream$class_object;

#endif	/* _JC_gnu_regexp_REFilterInputStream_H_ */
